============
Introduction
============

.. ⬇ Please keep this intro in sync with the README file. ⬇

Wpull is a Wget-compatible (or remake/clone/replacement/alternative) web
downloader and crawler.

.. image:: ../icon/wpull_logo_full.png
   :target: https://github.com/chfoo/wpull
   :alt: A dog pulling a box via a harness.

Features:

* Written in Python: lightweight & robust
* Familiar Wget options and behavior
* Graceful stopping and resuming
* Python & Lua scripting support
* Modular, extensible, & asynchronous API
* PhantomJS integration


.. ⬆ Please keep this intro above in sync with the README file. ⬆
   Additional intro stuff not in the README should go below.


Wpull is designed to be (almost) a drop-in replacement for Wget with
minimal changes to options. It is designed to run on much larger crawls
without requiring additional demand on resources.


Wpull's behavior is not an exact duplicate of Wget's behavior. As such,
you should not expect exact output and operation out of Wpull. However,
it aims to be a very useful alternative as its source code can be
easily modified to fix, change, or extend its behaviors.

